@@ -1,5 +1,5 @@
 $(document).ready(function(){
     window.setTimeout(function() { 
-        $(".alert-message").children('a').trigger('click');
+        $(".alert").children('a').trigger('click');
     }, 2000);
 });
